@@ -1,5 +1,4 @@
 import abc
-from typing import Any
 from typing import Type
 from typing import TypeVar
 
@@ -10,13 +9,15 @@ class PhantomMeta(abc.ABCMeta):
     actual instance creation.
     """
 
-    def __instancecheck__(self, instance: Any) -> bool:
+    def __instancecheck__(self, instance: object) -> bool:
         if not issubclass(self, Phantom):
             return False
         return self.__instancecheck__(instance)
 
-    def __call__(cls, instance):
-        return cls.from_instance(instance)  # type: ignore[attr-defined]
+    # With the current level of metaclass support in mypy it's unlikely that
+    # we'll be able to make this context typed, hence the ignores.
+    def __call__(cls, instance):  # type: ignore[no-untyped-def]
+        return cls.from_instance(instance)  # type: ignore[attr-defined,misc]
 
 
 Derived = TypeVar("Derived")
@@ -24,7 +25,7 @@ Derived = TypeVar("Derived")
 
 class Phantom(metaclass=PhantomMeta):
     @classmethod
-    def from_instance(cls: Type[Derived], instance: Any) -> Derived:
+    def from_instance(cls: Type[Derived], instance: object) -> Derived:
         if not isinstance(instance, cls):
             raise TypeError(
                 f"Can't create phantom type {cls.__qualname__} from {instance!r}"
@@ -33,5 +34,5 @@ class Phantom(metaclass=PhantomMeta):
 
     @classmethod
     @abc.abstractmethod
-    def __instancecheck__(cls, instance: Any) -> bool:
+    def __instancecheck__(cls, instance: object) -> bool:
         ...
